@@ -5,6 +5,6 @@ module.exports = {
   })],
   output: {
     format: 'es',
-    file: './dist/popper.js'
+    file: './packages/popper/dist/popper.js'
   }
 };
